package Data::Sah::CoerceBundle::App::cryp;

# AUTHOR
our $DATE = '2019-11-28'; # DATE
our $DIST = 'Data-Sah-CoerceBundle-App-cryp'; # DIST
our $VERSION = '0.008'; # VERSION

1;
# ABSTRACT: Coercion rules for the 'cryp' app family

__END__

=pod

=encoding UTF-8

=head1 NAME

Data::Sah::CoerceBundle::App::cryp - Coercion rules for the 'cryp' app family

=head1 VERSION

This document describes version 0.008 of Data::Sah::CoerceBundle::App::cryp (from Perl distribution Data-Sah-CoerceBundle-App-cryp), released on 2019-11-28.

=head1 HOMEPAGE

Please visit the project's homepage at L<https://metacpan.org/release/Data-Sah-CoerceBundle-App-cryp>.

=head1 SOURCE

Source repository is at L<https://github.com/perlancar/perl-Data-Sah-CoerceBundle-App-cryp>.

=head1 BUGS

Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=Data-Sah-CoerceBundle-App-cryp>

When submitting a bug or request, please include a test-file or a
patch to an existing test-file that illustrates the bug or desired
feature.

=head1 SEE ALSO

L<App::cryp> and C<App::cryp::*>

=head1 AUTHOR

perlancar <perlancar@cpan.org>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2019, 2018 by perlancar@cpan.org.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut
